@@ -1,9 +1,15 @@
 from contextlib import contextmanager
 from dataclasses import dataclass
+import ssl
+import os
+import requests
+from typing import Optional
+
 
 from dbt.adapters.base import Credentials
 from dbt.adapters.sql import SQLConnectionManager
 from dbt.logger import GLOBAL_LOGGER as logger
+from dbt.contracts.connection import AdapterResponse
 import dbt.exceptions
 
 import vertica_python
@@ -16,18 +22,28 @@ class verticaCredentials(Credentials):
     schema: str
     username: str
     password: str
+    ssl: bool = False
     port: int = 5433
     timeout: int = 3600
     withMaterialization: bool = False
-
+    ssl_env_cafile: Optional[str] = None
+    ssl_uri: Optional[str] = None
 
     @property
     def type(self):
         return 'vertica'
 
+    @property
+    def unique_field(self):
+        """
+        Hashed and included in anonymous telemetry to track adapter adoption.
+        Pick a field that can uniquely identify one team/organization building with this adapter
+        """
+        return self.host
+
     def _connection_keys(self):
         # return an iterator of keys to pretty-print in 'dbt debug'
-        return ('host','port','database','username', 'schema')
+        return ('host','port','database','username','schema')
 
 
 class verticaConnectionManager(SQLConnectionManager):
@@ -52,6 +68,23 @@ class verticaConnectionManager(SQLConnectionManager):
                 'connection_load_balance': True,
                 'session_label': f'dbt_{credentials.username}',
             }
+            # if credentials.ssl.lower() in {'true', 'yes', 'please'}:
+            if credentials.ssl:
+                if credentials.ssl_env_cafile is not None:
+                    context = ssl.create_default_context(
+                        cafile=os.environ.get(credentials.ssl_env_cafile),
+                    )
+                elif credentials.ssl_uri is not None:
+                    resp = requests.get(credentials.ssl_uri)
+                    resp.raise_for_status()
+                    ssl_data = resp.content
+                    context = ssl.create_default_context(
+                        cadata=ssl_data.decode("ascii", "ignore")
+                    )
+                else:
+                    context = ssl.create_default_context()
+                conn_info['ssl'] = context
+                logger.debug(f'SSL is on')
 
             handle = vertica_python.connect(**conn_info)
             connection.state = 'open'
@@ -65,7 +98,7 @@ class verticaConnectionManager(SQLConnectionManager):
             raise dbt.exceptions.FailedToConnectException(str(exc))
 
         # This is here mainly to support dbt-integration-tests.
-        # It globally enables WITH materialization for every connection dbt 
+        # It globally enables WITH materialization for every connection dbt
         # makes to Vertica. (Defaults to False)
         # Normal usage would be to use query HINT or declare session parameter in model or hook,
         # but tests do not support hooks and cannot change tests from dbt_utils
@@ -84,8 +117,15 @@ class verticaConnectionManager(SQLConnectionManager):
         return connection
 
     @classmethod
-    def get_status(cls, cursor):
-        return str(cursor.rowcount)
+    def get_response(cls, cursor):
+        code = cursor.description
+        rows = cursor.rowcount
+
+        return AdapterResponse(
+            _message="{} {}".format(code, rows),
+            rows_affected=rows,
+            code=code
+        )
 
     def cancel(self, connection):
         logger.debug(':P Cancel query')
@@ -104,4 +144,3 @@ class verticaConnectionManager(SQLConnectionManager):
             self.release()
             raise dbt.exceptions.RuntimeException(str(exc))
 
-
